@@ -1,9 +1,11 @@
 from . import datatools
 from . import fmn_plottools
 from . import fmn_datatools
+from . import fmn_tts
 
 __all__ = [
     'datatools',
     'fmn_plottools',
-    'fmn_datatools.py'
+    'fmn_datatools',
+    'fmn_tts'
 ]
